@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.osconfig_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -62,7 +74,7 @@ class OsConfigServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[OsConfigServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -323,7 +335,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -378,8 +390,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, OsConfigServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, OsConfigServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the os config service client.
@@ -393,7 +405,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             transport (Union[str, OsConfigServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -423,6 +435,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -475,10 +488,10 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def execute_patch_job(
         self,
-        request: Union[patch_jobs.ExecutePatchJobRequest, dict] = None,
+        request: Optional[Union[patch_jobs.ExecutePatchJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_jobs.PatchJob:
         r"""Patch VM instances by creating and running a patch
@@ -565,11 +578,11 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def get_patch_job(
         self,
-        request: Union[patch_jobs.GetPatchJobRequest, dict] = None,
+        request: Optional[Union[patch_jobs.GetPatchJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_jobs.PatchJob:
         r"""Get the patch job. This can be used to track the
@@ -677,10 +690,10 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def cancel_patch_job(
         self,
-        request: Union[patch_jobs.CancelPatchJobRequest, dict] = None,
+        request: Optional[Union[patch_jobs.CancelPatchJobRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_jobs.PatchJob:
         r"""Cancel a patch job. The patch job must be active.
@@ -766,11 +779,11 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def list_patch_jobs(
         self,
-        request: Union[patch_jobs.ListPatchJobsRequest, dict] = None,
+        request: Optional[Union[patch_jobs.ListPatchJobsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPatchJobsPager:
         r"""Get a list of patch jobs.
@@ -879,11 +892,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def list_patch_job_instance_details(
         self,
-        request: Union[patch_jobs.ListPatchJobInstanceDetailsRequest, dict] = None,
+        request: Optional[
+            Union[patch_jobs.ListPatchJobInstanceDetailsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPatchJobInstanceDetailsPager:
         r"""Get a list of instance details for a given patch job.
@@ -996,13 +1011,15 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def create_patch_deployment(
         self,
-        request: Union[patch_deployments.CreatePatchDeploymentRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.CreatePatchDeploymentRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
-        patch_deployment: patch_deployments.PatchDeployment = None,
-        patch_deployment_id: str = None,
+        parent: Optional[str] = None,
+        patch_deployment: Optional[patch_deployments.PatchDeployment] = None,
+        patch_deployment_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Create an OS Config patch deployment.
@@ -1130,11 +1147,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def get_patch_deployment(
         self,
-        request: Union[patch_deployments.GetPatchDeploymentRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.GetPatchDeploymentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Get an OS Config patch deployment.
@@ -1236,11 +1255,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def list_patch_deployments(
         self,
-        request: Union[patch_deployments.ListPatchDeploymentsRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.ListPatchDeploymentsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPatchDeploymentsPager:
         r"""Get a page of OS Config patch deployments.
@@ -1351,11 +1372,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def delete_patch_deployment(
         self,
-        request: Union[patch_deployments.DeletePatchDeploymentRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.DeletePatchDeploymentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Delete an OS Config patch deployment.
@@ -1441,12 +1464,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def update_patch_deployment(
         self,
-        request: Union[patch_deployments.UpdatePatchDeploymentRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.UpdatePatchDeploymentRequest, dict]
+        ] = None,
         *,
-        patch_deployment: patch_deployments.PatchDeployment = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        patch_deployment: Optional[patch_deployments.PatchDeployment] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Update an OS Config patch deployment.
@@ -1559,11 +1584,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def pause_patch_deployment(
         self,
-        request: Union[patch_deployments.PausePatchDeploymentRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.PausePatchDeploymentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Change state of patch deployment to "PAUSED".
@@ -1667,11 +1694,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def resume_patch_deployment(
         self,
-        request: Union[patch_deployments.ResumePatchDeploymentRequest, dict] = None,
+        request: Optional[
+            Union[patch_deployments.ResumePatchDeploymentRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Change state of patch deployment back to "ACTIVE".
@@ -1787,14 +1816,9 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-os-config",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("OsConfigServiceClient",)
