@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
@@ -42,7 +44,7 @@ class VulnerabilityReport(proto.Message):
 
             Format:
             ``projects/{project_number}/locations/{location}/instances/{instance_id}/vulnerabilityReport``
-        vulnerabilities (Sequence[google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability]):
+        vulnerabilities (MutableSequence[google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability]):
             Output only. List of vulnerabilities
             affecting the VM.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
@@ -57,14 +59,14 @@ class VulnerabilityReport(proto.Message):
             details (google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability.Details):
                 Contains metadata as per the upstream feed of
                 the operating system and NVD.
-            installed_inventory_item_ids (Sequence[str]):
+            installed_inventory_item_ids (MutableSequence[str]):
                 Corresponds to the ``INSTALLED_PACKAGE`` inventory item on
                 the VM. This field displays the inventory items affected by
                 this vulnerability. If the vulnerability report was not
                 updated after the VM inventory update, these values might
                 not display in VM inventory. For some distros, this field
                 may be empty.
-            available_inventory_item_ids (Sequence[str]):
+            available_inventory_item_ids (MutableSequence[str]):
                 Corresponds to the ``AVAILABLE_PACKAGE`` inventory item on
                 the VM. If the vulnerability report was not updated after
                 the VM inventory update, these values might not display in
@@ -78,7 +80,7 @@ class VulnerabilityReport(proto.Message):
             update_time (google.protobuf.timestamp_pb2.Timestamp):
                 The timestamp for when the vulnerability was
                 last modified.
-            items (Sequence[google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability.Item]):
+            items (MutableSequence[google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability.Item]):
                 List of items affected by the vulnerability.
         """
 
@@ -107,7 +109,7 @@ class VulnerabilityReport(proto.Message):
                 description (str):
                     The note or description describing the
                     vulnerability from the distro.
-                references (Sequence[google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability.Details.Reference]):
+                references (MutableSequence[google.cloud.osconfig_v1.types.VulnerabilityReport.Vulnerability.Details.Reference]):
                     Corresponds to the references attached to the
                     ``VulnerabilityDetails``.
             """
@@ -122,37 +124,39 @@ class VulnerabilityReport(proto.Message):
                         The source of the reference e.g. NVD.
                 """
 
-                url = proto.Field(
+                url: str = proto.Field(
                     proto.STRING,
                     number=1,
                 )
-                source = proto.Field(
+                source: str = proto.Field(
                     proto.STRING,
                     number=2,
                 )
 
-            cve = proto.Field(
+            cve: str = proto.Field(
                 proto.STRING,
                 number=1,
             )
-            cvss_v2_score = proto.Field(
+            cvss_v2_score: float = proto.Field(
                 proto.FLOAT,
                 number=2,
             )
-            cvss_v3 = proto.Field(
+            cvss_v3: "CVSSv3" = proto.Field(
                 proto.MESSAGE,
                 number=3,
                 message="CVSSv3",
             )
-            severity = proto.Field(
+            severity: str = proto.Field(
                 proto.STRING,
                 number=4,
             )
-            description = proto.Field(
+            description: str = proto.Field(
                 proto.STRING,
                 number=5,
             )
-            references = proto.RepeatedField(
+            references: MutableSequence[
+                "VulnerabilityReport.Vulnerability.Details.Reference"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=6,
                 message="VulnerabilityReport.Vulnerability.Details.Reference",
@@ -187,62 +191,64 @@ class VulnerabilityReport(proto.Message):
                     fixes the vulnerability.
             """
 
-            installed_inventory_item_id = proto.Field(
+            installed_inventory_item_id: str = proto.Field(
                 proto.STRING,
                 number=1,
             )
-            available_inventory_item_id = proto.Field(
+            available_inventory_item_id: str = proto.Field(
                 proto.STRING,
                 number=2,
             )
-            fixed_cpe_uri = proto.Field(
+            fixed_cpe_uri: str = proto.Field(
                 proto.STRING,
                 number=3,
             )
-            upstream_fix = proto.Field(
+            upstream_fix: str = proto.Field(
                 proto.STRING,
                 number=4,
             )
 
-        details = proto.Field(
+        details: "VulnerabilityReport.Vulnerability.Details" = proto.Field(
             proto.MESSAGE,
             number=1,
             message="VulnerabilityReport.Vulnerability.Details",
         )
-        installed_inventory_item_ids = proto.RepeatedField(
+        installed_inventory_item_ids: MutableSequence[str] = proto.RepeatedField(
             proto.STRING,
             number=2,
         )
-        available_inventory_item_ids = proto.RepeatedField(
+        available_inventory_item_ids: MutableSequence[str] = proto.RepeatedField(
             proto.STRING,
             number=3,
         )
-        create_time = proto.Field(
+        create_time: timestamp_pb2.Timestamp = proto.Field(
             proto.MESSAGE,
             number=4,
             message=timestamp_pb2.Timestamp,
         )
-        update_time = proto.Field(
+        update_time: timestamp_pb2.Timestamp = proto.Field(
             proto.MESSAGE,
             number=5,
             message=timestamp_pb2.Timestamp,
         )
-        items = proto.RepeatedField(
+        items: MutableSequence[
+            "VulnerabilityReport.Vulnerability.Item"
+        ] = proto.RepeatedField(
             proto.MESSAGE,
             number=6,
             message="VulnerabilityReport.Vulnerability.Item",
         )
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    vulnerabilities = proto.RepeatedField(
+    vulnerabilities: MutableSequence[Vulnerability] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message=Vulnerability,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
@@ -266,7 +272,7 @@ class GetVulnerabilityReportRequest(proto.Message):
             provided.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -297,19 +303,19 @@ class ListVulnerabilityReportsRequest(proto.Message):
             in the response.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -320,7 +326,7 @@ class ListVulnerabilityReportsResponse(proto.Message):
     VM instances in the specified location.
 
     Attributes:
-        vulnerability_reports (Sequence[google.cloud.osconfig_v1.types.VulnerabilityReport]):
+        vulnerability_reports (MutableSequence[google.cloud.osconfig_v1.types.VulnerabilityReport]):
             List of vulnerabilityReport objects.
         next_page_token (str):
             The pagination token to retrieve the next
@@ -331,12 +337,12 @@ class ListVulnerabilityReportsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    vulnerability_reports = proto.RepeatedField(
+    vulnerability_reports: MutableSequence["VulnerabilityReport"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="VulnerabilityReport",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -450,54 +456,54 @@ class CVSSv3(proto.Message):
         IMPACT_LOW = 2
         IMPACT_NONE = 3
 
-    base_score = proto.Field(
+    base_score: float = proto.Field(
         proto.FLOAT,
         number=1,
     )
-    exploitability_score = proto.Field(
+    exploitability_score: float = proto.Field(
         proto.FLOAT,
         number=2,
     )
-    impact_score = proto.Field(
+    impact_score: float = proto.Field(
         proto.FLOAT,
         number=3,
     )
-    attack_vector = proto.Field(
+    attack_vector: AttackVector = proto.Field(
         proto.ENUM,
         number=5,
         enum=AttackVector,
     )
-    attack_complexity = proto.Field(
+    attack_complexity: AttackComplexity = proto.Field(
         proto.ENUM,
         number=6,
         enum=AttackComplexity,
     )
-    privileges_required = proto.Field(
+    privileges_required: PrivilegesRequired = proto.Field(
         proto.ENUM,
         number=7,
         enum=PrivilegesRequired,
     )
-    user_interaction = proto.Field(
+    user_interaction: UserInteraction = proto.Field(
         proto.ENUM,
         number=8,
         enum=UserInteraction,
     )
-    scope = proto.Field(
+    scope: Scope = proto.Field(
         proto.ENUM,
         number=9,
         enum=Scope,
     )
-    confidentiality_impact = proto.Field(
+    confidentiality_impact: Impact = proto.Field(
         proto.ENUM,
         number=10,
         enum=Impact,
     )
-    integrity_impact = proto.Field(
+    integrity_impact: Impact = proto.Field(
         proto.ENUM,
         number=11,
         enum=Impact,
     )
-    availability_impact = proto.Field(
+    availability_impact: Impact = proto.Field(
         proto.ENUM,
         number=12,
         enum=Impact,
