@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -47,12 +49,12 @@ class FixedOrPercent(proto.Message):
             This field is a member of `oneof`_ ``mode``.
     """
 
-    fixed = proto.Field(
+    fixed: int = proto.Field(
         proto.INT32,
         number=1,
         oneof="mode",
     )
-    percent = proto.Field(
+    percent: int = proto.Field(
         proto.INT32,
         number=2,
         oneof="mode",
